pub struct BatchProcessor { /* private fields */ }Expand description
O(1) batch processor for fixed-size batch accumulation.
Accumulates items until batch is full, then signals ready for processing. Common pattern for batching network writes, disk flushes, metric exports.
Implementations
Sourceimpl BatchProcessor
impl BatchProcessor
Sourcepub fn for_network() -> Self
pub fn for_network() -> Self
Create for network operations (batch size 1000)
Sourcepub fn for_metrics() -> Self
pub fn for_metrics() -> Self
Create for metrics export (batch size 50)
Sourcepub fn add_many(&mut self, n: u64) -> u64
pub fn add_many(&mut self, n: u64) -> u64
Add multiple items, returns number of batches completed
Sourcepub fn fill_percentage(&self) -> f64
pub fn fill_percentage(&self) -> f64
Get current batch fill percentage
Sourcepub fn batches_completed(&self) -> u64
pub fn batches_completed(&self) -> u64
Get total batches completed
Sourcepub fn total_items(&self) -> u64
pub fn total_items(&self) -> u64
Get total items processed