Theme system with CIELAB perceptual gradients.
Provides color themes and smooth gradient interpolation for terminal UIs. Based on trueno-viz theme system for visual consistency.
Theme system with CIELAB perceptual gradients.
Provides color themes and smooth gradient interpolation for terminal UIs. Based on trueno-viz theme system for visual consistency.