pub struct MemoryBar { /* private fields */ }Expand description
Stacked memory bar with labeled segments.
Implementations
Sourceimpl MemoryBar
impl MemoryBar
Sourcepub fn from_usage(
used_bytes: u64,
cached_bytes: u64,
swap_used: u64,
swap_total: u64,
total_bytes: u64,
) -> Self
pub fn from_usage( used_bytes: u64, cached_bytes: u64, swap_used: u64, swap_total: u64, total_bytes: u64, ) -> Self
Create from common memory info values.
Sourcepub fn add_segment(&mut self, segment: MemorySegment)
pub fn add_segment(&mut self, segment: MemorySegment)
Add a segment.
Sourcepub fn segment(self, name: impl Into<String>, bytes: u64, color: Color) -> Self
pub fn segment(self, name: impl Into<String>, bytes: u64, color: Color) -> Self
Add a segment (builder pattern for chaining).
Sourcepub fn with_bar_width(self, width: usize) -> Self
pub fn with_bar_width(self, width: usize) -> Self
Set bar width.
Sourcepub fn without_labels(self) -> Self
pub fn without_labels(self) -> Self
Hide labels.
Sourcepub fn without_values(self) -> Self
pub fn without_values(self) -> Self
Hide values.
Sourcepub fn with_huge_pages(self, huge_pages: HugePages) -> Self
pub fn with_huge_pages(self, huge_pages: HugePages) -> Self
Set huge pages statistics (SPEC-024 CB-MEM-006).
When enabled, huge pages are displayed as an additional row/indicator.
Sourcepub fn show_huge_pages(self, show: bool) -> Self
pub fn show_huge_pages(self, show: bool) -> Self
Enable/disable huge pages display.
Sourcepub fn set_huge_pages(&mut self, huge_pages: HugePages)
pub fn set_huge_pages(&mut self, huge_pages: HugePages)
Update huge pages data.
Sourcepub fn huge_pages(&self) -> Option<&HugePages>
pub fn huge_pages(&self) -> Option<&HugePages>
Get huge pages statistics, if set.
Sourcepub fn has_huge_pages(&self) -> bool
pub fn has_huge_pages(&self) -> bool
Check if huge pages are configured and being tracked.
Sourcepub fn usage_percent(&self) -> f64
pub fn usage_percent(&self) -> f64
Get usage percentage.